@@ -15,6 +15,7 @@ from dataclasses import dataclass
 from typing import List, Dict, Union, Tuple, Any
 from urllib.parse import urlparse
 
+import speechmatics.adapters
 from speechmatics.client import WebsocketClient
 from speechmatics.batch_client import BatchClient
 from speechmatics.models import (
@@ -24,6 +25,7 @@ from speechmatics.models import (
     ServerMessageType,
     ConnectionSettings,
     BatchTranscriptionConfig,
+    BatchSpeakerDiarizationConfig,
     RTSpeakerDiarizationConfig,
 )
 
@@ -165,23 +167,25 @@ def get_connection_settings(args):
     :return: Settings for the WebSocket connection.
     :rtype: speechmatics.models.ConnectionSettings
     """
-
     settings = ConnectionSettings(
-        url=args["url"], message_buffer_size=args.get("buffer_size")
+        url=args.get("url"),
+        auth_token=args.get("auth_token"),
+        generate_temp_token=True if args.get("generate_temp_token", False) else None,
     )
 
+    if args.get("buffer_size") is not None:
+        settings.message_buffer_size = args["buffer_size"]
+
     if args.get("ssl_mode") == "insecure":
         settings.ssl_context.check_hostname = False
         settings.ssl_context.verify_mode = ssl.CERT_NONE
-    elif args["ssl_mode"] == "none":
+    elif args.get("ssl_mode") == "none":
         settings.ssl_context = None
 
-    settings.auth_token = args["auth_token"]
-
     return settings
 
 
-def get_transcription_config(args):
+def get_transcription_config(args):  # pylint: disable=too-many-branches
     """
     Helper function which returns a TranscriptionConfig object based on the
     command line options given to the program.
@@ -193,19 +197,34 @@ def get_transcription_config(args):
     :rtype: speechmatics.models.TranscriptionConfig |
     speechmatics.models.BatchTranscriptionConfig
     """
-    config = dict(
-        language=args.get("language", "en"),
-        domain=args.get("domain"),
-        output_locale=args.get("output_locale"),
-        operating_point=args.get("operating_point", "standard"),
-        enable_partials=True if args.get("enable_partials", False) else None,
-        enable_entities=True if args.get("enable_entities", False) else None,
-        max_delay=args.get("max_delay"),
-        max_delay_mode=args.get("max_delay_mode"),
-        diarization=args.get("diarization"),
-        speaker_change_sensitivity=args.get("speaker_change_sensitivity"),
-        speaker_diarization_sensitivity=args.get("speaker_diarization_sensitivity"),
-    )
+    # First get configuration from a config file if one is provided.
+    if args.get("config_file"):
+        with open(args["config_file"], encoding="utf-8") as config_file:
+            config = json.load(config_file)
+    else:
+        # Ensure "en" is the default language as to not break existing API behavior.
+        config = {"language": "en"}
+
+    # Explicit command line arguments override values from config file.
+    for option in [
+        "language",
+        "domain",
+        "output_locale",
+        "operating_point",
+        "max_delay",
+        "max_delay_mode",
+        "diarization",
+        "channel_diarization_labels",
+        "speaker_change_sensitivity",
+        "speaker_diarization_sensitivity",
+    ]:
+        if args.get(option) is not None:
+            config[option] = args[option]
+    for option in [
+        "enable_partials",
+        "enable_entities",
+    ]:
+        config[option] = True if args.get(option) else config.get(option)
 
     if args.get("additional_vocab_file"):
         additional_vocab = parse_additional_vocab(args["additional_vocab_file"])
@@ -243,9 +262,11 @@ def get_transcription_config(args):
             max_speakers=max_speakers
         )
 
-    if args.get("channel_diarization_labels") is not None:
-        labels_str = args.get("channel_diarization_labels")
-        config["channel_diarization_labels"] = labels_str
+    if args.get("speaker_diarization_sensitivity") is not None:
+        speaker_sensitivity = args.get("speaker_diarization_sensitivity")
+        config["speaker_diarization_config"] = BatchSpeakerDiarizationConfig(
+            speaker_sensitivity=speaker_sensitivity
+        )
 
     if args["mode"] == "rt":
         # pylint: disable=unexpected-keyword-arg
@@ -281,6 +302,7 @@ def add_printing_handlers(
     enable_partials=False,
     debug_handlers_too=False,
     speaker_change_token=False,
+    print_json=False,
 ):
     """
     Adds a set of handlers to the websocket client which print out transcripts
@@ -312,18 +334,34 @@ def add_printing_handlers(
 
     def partial_transcript_handler(message):
         # "\n" does not appear in partial transcripts
-        print(f'{message["metadata"]["transcript"]}', end="\r", file=sys.stderr)
+        if print_json:
+            print(json.dumps(message))
+            return
+        plaintext = speechmatics.adapters.convert_to_txt(
+            message["results"],
+            api.transcription_config.language,
+            language_pack_info=api.get_language_pack_info(),
+            speaker_labels=True,
+            speaker_change_token=speaker_change_token,
+        )
+        if plaintext:
+            print(plaintext, end="\r", file=sys.stderr)
 
     def transcript_handler(message):
         transcripts.json.append(message)
-        transcript = message["metadata"]["transcript"]
-        if transcript:
-            transcript_to_print = transcript
-            if speaker_change_token:
-                transcript_with_sc_token = transcript.replace("\n", "\n<sc>\n")
-                transcript_to_print = transcript_with_sc_token
-            transcripts.text += transcript_to_print
-            print(transcript_to_print)
+        if print_json:
+            print(json.dumps(message))
+            return
+        plaintext = speechmatics.adapters.convert_to_txt(
+            message["results"],
+            api.transcription_config.language,
+            language_pack_info=api.get_language_pack_info(),
+            speaker_labels=True,
+            speaker_change_token=speaker_change_token,
+        )
+        if plaintext:
+            print(plaintext)
+        transcripts.text += plaintext
 
     def end_of_transcript_handler(_):
         if enable_partials:
@@ -453,6 +491,7 @@ def rt_main(args):
         enable_partials=args["enable_partials"],
         debug_handlers_too=args["debug"],
         speaker_change_token=args["speaker_change_token"],
+        print_json=args["print_json"],
     )
 
     def run(stream):
@@ -585,15 +624,35 @@ def parse_args(args=None):
             " With `none` then SSL is not used."
         ),
     )
+    connection_parser.add_argument(
+        "--generate-temp-token",
+        default=None,
+        action="store_true",
+        help=(
+            "Automatically generate a temporary token for authentication."
+            "Non-enterprise customers must set this to True."
+            "Enterprise customers should set this to False."
+        ),
+    )
 
     # Parent parser for shared params related to building a job config
     config_parser = argparse.ArgumentParser(add_help=False)
+
+    config_parser.add_argument(
+        "--config-file",
+        dest="config_file",
+        type=str,
+        default=None,
+        help="Read the transcription config from a file."
+        " If you provide this, all other config options work as overrides.",
+    )
+
     config_parser.add_argument(
         "--lang",
         "--language",
         dest="language",
         type=str,
-        default="en",
+        default=None,
         help="Language (ISO 639-1 code, e.g. en, fr, de).",
     )
     config_parser.add_argument(
@@ -765,7 +824,6 @@ def parse_args(args=None):
             "values which are too small create unnecessary overhead."
         ),
     )
-
     rt_transcribe_command_parser.add_argument(
         "--buffer-size",
         default=512,
@@ -775,6 +833,15 @@ def parse_args(args=None):
             "acknowledgements from the server."
         ),
     )
+    rt_transcribe_command_parser.add_argument(
+        "--print-json",
+        default=False,
+        action="store_true",
+        help=(
+            "Print the JSON partial & final transcripts received rather than "
+            "plaintext messages."
+        ),
+    )
 
     rt_transcribe_command_parser.add_argument(
         "--diarization",
