@@ -8,10 +8,14 @@ import asyncio
 import copy
 import json
 import logging
-import sys
 import traceback
 
 import websockets
+import httpx
+
+from websockets.exceptions import (
+    WebSocketException,
+)
 
 from speechmatics.exceptions import (
     EndOfTranscriptException,
@@ -55,6 +59,7 @@ class WebsocketClient:
 
         self.seq_no = 0
         self.session_running = False
+        self._language_pack_info = None
         self._transcription_config_needs_update = False
         self._session_needs_closing = False
 
@@ -85,6 +90,24 @@ class WebsocketClient:
         """
         self._recognition_started.set()
 
+    def _set_language_pack_info(self, language_pack_info: dict):
+        """
+        Update the `language_pack_info` which is a subset of information from the
+        manifest in the language pack which we expose to end users via the
+        RecognitionStarted message.
+        """
+        self._language_pack_info = language_pack_info
+
+    def get_language_pack_info(self) -> dict:
+        """
+        Get the `language_pack_info` which is a subset of information from the
+        manifest in the language pack which we expose to end users.
+
+        Can be None if this field has not yet been set - i.e. if the RecognitionStarted
+        message has not been received yet.
+        """
+        return self._language_pack_info
+
     @json_utf8
     def _set_recognition_config(self):
         """
@@ -158,6 +181,8 @@ class WebsocketClient:
 
         if message_type == ServerMessageType.RecognitionStarted:
             self._flag_recognition_started()
+            if "language_pack_info" in message:
+                self._set_language_pack_info(message["language_pack_info"])
         elif message_type == ServerMessageType.AudioAdded:
             self._buffer_semaphore.release()
         elif message_type == ServerMessageType.EndOfTranscript:
@@ -376,13 +401,24 @@ class WebsocketClient:
         """
         self.transcription_config = transcription_config
         self.seq_no = 0
+        self._language_pack_info = None
         await self._init_synchronization_primitives()
-
         extra_headers = {}
-        if self.connection_settings.auth_token is not None:
+        if (
+            not self.connection_settings.generate_temp_token
+            and self.connection_settings.auth_token is not None
+        ):
             token = f"Bearer {self.connection_settings.auth_token}"
             extra_headers["Authorization"] = token
 
+        if (
+            self.connection_settings.generate_temp_token
+            and self.connection_settings.auth_token is not None
+        ):
+            temp_token = await _get_temp_token(self.connection_settings.auth_token)
+            token = f"Bearer {temp_token}"
+            extra_headers["Authorization"] = token
+
         try:
             async with websockets.connect(  # pylint: disable=no-member
                 self.connection_settings.url,
@@ -402,7 +438,13 @@ class WebsocketClient:
                 "support SSL. If this is the case then try using "
                 "--ssl-mode=none"
             )
-            sys.exit(1)
+            raise
+        except WebSocketException:
+            traceback.print_exc()
+            LOGGER.error(
+                "Caught WebSocketException when attempting to connect to server."
+            )
+            raise
         finally:
             self.session_running = False
             self._session_needs_closing = False
@@ -424,3 +466,30 @@ class WebsocketClient:
         """
         # pylint: disable=no-value-for-parameter
         asyncio.run(asyncio.wait_for(self.run(*args, **kwargs), timeout=timeout))
+
+
+async def _get_temp_token(api_key):
+    """
+    Used to get a temporary token from management platform api for SaaS users
+    """
+    mp_api_url = "https://mp.speechmatics.com"
+    endpoint = mp_api_url + "/v1/api_keys"
+    params = {"type": "rt"}
+    body = {"ttl": 60}
+    headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
+    # pylint: disable=no-member
+    try:
+        response = httpx.post(endpoint, json=body, params=params, headers=headers)
+        response.read()
+        response.raise_for_status()
+        key_object = response.json()
+        return key_object["key_value"]
+    except httpx.HTTPError as exc:
+        traceback.print_exc()
+        LOGGER.error(
+            "Error response %s while generating temporary token from %s. Details: %s",
+            exc.response.status_code,
+            exc.request.url,
+            exc.response.text,
+        )
+        raise exc
