@@ -308,8 +308,12 @@ def test_helpful_error_message_received_on_connection_reset_error():
 
     with patch("websockets.connect", mock_connect):
         with patch.object(client.LOGGER, "error", mock_logger_error_method):
-            with pytest.raises(SystemExit) as ex:
+            try:
                 ws_client.run_synchronously(MagicMock(), MagicMock(), MagicMock())
+            except ConnectionResetError as exc:
+                assert exc is not None
+            else:
+                assert False  # we should not reach else
             mock_logger_error_method.assert_called_once()
             # pylint: disable=unsubscriptable-object
             assert (
@@ -319,7 +323,6 @@ def test_helpful_error_message_received_on_connection_reset_error():
                 # function, pylint doesn't like this.
                 in mock_logger_error_method.call_args[0][0]
             )
-            assert ex.value.code == 1
 
 
 @pytest.mark.asyncio
@@ -530,6 +533,21 @@ async def test__producer_semaphore_timeout(mocker):
     assert len(msgs) == buffer_size
 
 
+def test_language_pack_info_is_stored(mock_server):
+    """
+    Tests that `language_pack_info` from the `RecognitionStarted` message is stored by the client.
+    """
+    ws_client, transcription_config, audio_settings = default_ws_client_setup(
+        mock_server.url
+    )
+    with open(path_to_test_resource("ch.wav"), "rb") as audio_stream:
+        ws_client.run_synchronously(audio_stream, transcription_config, audio_settings)
+
+    info = ws_client.get_language_pack_info()
+    assert info is not None
+    assert info["language_code"] == "en"
+
+
 def deepcopy_state(obj):
     """
     Return a deepcopy of the __dict__ (or state) of an object but ignore
